/// <reference types="react" />
import React$1, { MouseEvent } from 'react';

declare type ButtonVariants = "primary" | "secondary" | "success" | "danger" | "warning" | "default";
declare type ButtonTypes = "filled" | "outlined" | "ghost";
declare type ButtonSizes = "small" | "medium" | "large";
interface ButtonState {
    disabled?: boolean;
}
interface ButtonProps {
    variant?: ButtonVariants;
    type?: ButtonTypes;
    size?: ButtonSizes;
    onClick?: (event?: MouseEvent<HTMLButtonElement>) => void;
    state?: ButtonState;
    children?: React.ReactNode;
    customClass?: string;
    customStyles?: React.CSSProperties;
}

declare const Button: ({ variant, size, type, onClick, state, children, customClass, customStyles, }: ButtonProps) => JSX.Element;

declare const LeCSS: () => JSX.Element;

declare type TopographyTypes = "h1" | "h2" | "h3" | "h4" | "h5" | "h6" | "subtitle-1" | "subtitle-2" | "body-1" | "body-2" | "caption" | "button" | "overline";
interface TopographyProps {
    children?: React$1.ReactNode;
    type: TopographyTypes;
    customClass?: string;
    customStyles?: React$1.CSSProperties;
}

declare const Topography: ({ type, children, customClass, customStyles, }: TopographyProps) => JSX.Element;

interface GridProps {
    cols?: React$1.CSSProperties["gridTemplateColumns"] | number;
    rows?: React$1.CSSProperties["gridTemplateRows"] | number;
    gap?: {
        row?: React$1.CSSProperties["rowGap"];
        col?: React$1.CSSProperties["columnGap"];
    };
    width?: React$1.CSSProperties["width"];
    padding?: React$1.CSSProperties["padding"];
    children?: React$1.ReactNode;
    customStyles?: React$1.CSSProperties;
    customClass?: string;
}

declare const Grid: ({ rows, cols, gap, width, padding, children, customClass, customStyles, }: GridProps) => JSX.Element;

declare type BoxVariants = "primary" | "secondary" | "success" | "danger" | "warning" | "default";
declare type BoxTextColor = "dark" | "light" | "darker" | "lighter";
interface BoxProps {
    bgColor?: BoxVariants;
    textColor?: BoxTextColor;
    centered?: boolean;
    width?: React.CSSProperties["width"];
    height?: React.CSSProperties["height"];
    padding?: React.CSSProperties["margin"];
    margin?: React.CSSProperties["margin"];
    borderRadius?: React.CSSProperties["borderRadius"];
    customClass?: string;
    customStyles?: React.CSSProperties;
    children?: React.ReactNode;
    gridSpan?: {
        row?: number;
        col?: number;
    };
}

declare const Box: ({ width, children, padding, margin, height, bgColor, borderRadius, customClass, customStyles, centered, textColor, gridSpan, }: BoxProps) => JSX.Element;

declare type BadgeTypes = "dashed" | "ghost" | "outlined";
declare type BadgeVariants = "primary" | "secondary" | "success" | "danger" | "warning" | "default";
declare type BadgeSizes = "small" | "medium" | "large";
interface BadgeProps {
    type?: BadgeTypes;
    variant?: BadgeVariants;
    children?: React$1.ReactNode;
    size?: BadgeSizes;
    customClass?: string;
    customStyles?: React$1.CSSProperties;
}

declare const Badge: ({ type, variant, children, size, customStyles, customClass, }: BadgeProps) => JSX.Element;

declare type LeSizes = "small" | "medium" | "large";
declare type LeVariants = "primary" | "secondary" | "success" | "danger" | "warning" | "default";

export { Badge, BadgeProps, BadgeTypes, Box, BoxProps, BoxVariants, Button, ButtonProps, ButtonState, ButtonTypes, ButtonVariants, Grid, LeCSS, LeSizes, LeVariants, Topography, TopographyProps, TopographyTypes };
